Chapter 3: Probability and Statistical Distributions
----------------------------------------------------
This chapter discusses basic foundational principles, including probability
and basic descriptive statistics. It also introduces several important
probability distribution functions.
